@@ -1,9 +1,12 @@
 import json
 import requests
 import time
+import logging
 import datakitchen_api_tools.dk_api_helpers as dk_api_helpers
 from datakitchen_api_tools.DKOrder import DKOrder
+from datakitchen_api_tools.DKExceptions import *
 
+logger = logging.getLogger("datakitchen_api_tools.DkConnection")
 
 class DKConnection():
     def __init__(self, hostname, username, password, timeout=1):
@@ -21,21 +24,28 @@ class DKConnection():
         payload = {'parameters': overrides}
         return requests.put(url, headers=headers, data=json.dumps(payload))
 
-    def safeCreateOrder(self, kitchen, recipe, variation, overrides={}, wait_time=10, timeout=100000):
+    def safeCreateOrder(self, kitchen, recipe, variation, overrides={}, wait_time=10, timeout=100000, test_level=""):
         response = self.createOrder(kitchen, recipe, variation, overrides=overrides)
         if response.status_code != 200:
-            raise Exception
+            logger.error("Error Starting Order %s %s %s." % (kitchen, recipe, variation))
+            raise DKOrderException
         order = json.loads(response.text)
         order_id = order['order_id']
         order_run = self.getOrder(kitchen, order_id)
         time.sleep(wait_time)
         time_running = 0
-        while (order_run.getOrderStatus() == "ACTIVE_ORDER" or order_run.getOrderStatus() == "PLANNED_SERVING") and time_running < timeout:
+        while order_run.isOrderRunning() and time_running < timeout:
             time.sleep(wait_time)
             order_run = self.getOrder(kitchen, order_id)
             time_running += wait_time
         if time_running >= timeout:
-            raise Exception
+            raise DKTimeoutException
+        if not order_run.didOrderCompleteSuccesfully():
+            logger.error("Order %s, %s, %s Failed." % (kitchen, recipe, variation))
+            raise DKOrderRunErrorException
+        if len(order_run.getFailedTests(test_level)) > 0:
+            logger.error("Tests in Order  %s, %s, %s Failed." % (kitchen, recipe, variation))
+            raise DKOrderRunFailedTestException
         return order_run
 
     def OrderRunInfo(self, kitchen, order_id):
